[PATCH] D73857: [NFC][ScalarEvolution] Fix typo in getRangeForAffineAR and getRangeViaFactoring

Zhongduo Lin (Jimmy) via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Sun Feb 2 14:59:01 PST 2020


zhongduo created this revision.
zhongduo added reviewers: sanjoy, sanjoy.google, mzolotukhin.
Herald added a project: LLVM.
Herald added a subscriber: llvm-commits.

Simple typo fix in ScalarEvolution.h. The AddRec is {start, +, step} rather than {start, +, stop}. The definition in cpp file has the right name.


https://reviews.llvm.org/D73857

Files:
  llvm/include/llvm/Analysis/ScalarEvolution.h


Index: llvm/include/llvm/Analysis/ScalarEvolution.h
===================================================================
--- llvm/include/llvm/Analysis/ScalarEvolution.h
+++ llvm/include/llvm/Analysis/ScalarEvolution.h
@@ -1443,15 +1443,15 @@
   /// copied if its needed for longer.
   const ConstantRange &getRangeRef(const SCEV *S, RangeSignHint Hint);
 
   /// Determines the range for the affine SCEVAddRecExpr {\p Start,+,\p Stop}.
   /// Helper for \c getRange.
-  ConstantRange getRangeForAffineAR(const SCEV *Start, const SCEV *Stop,
+  ConstantRange getRangeForAffineAR(const SCEV *Start, const SCEV *Step,
                                     const SCEV *MaxBECount, unsigned BitWidth);
 
   /// Try to compute a range for the affine SCEVAddRecExpr {\p Start,+,\p
   /// Stop} by "factoring out" a ternary expression from the add recurrence.
   /// Helper called by \c getRange.
-  ConstantRange getRangeViaFactoring(const SCEV *Start, const SCEV *Stop,
+  ConstantRange getRangeViaFactoring(const SCEV *Start, const SCEV *Step,
                                      const SCEV *MaxBECount, unsigned BitWidth);
 
   /// We know that there is no SCEV for the specified value.  Analyze the


-------------- next part --------------
@@ -1443,15 +1443,15 @@
   const ConstantRange &getRangeRef(const SCEV *S, RangeSignHint Hint);
 
-  /// Determines the range for the affine SCEVAddRecExpr {\p Start,+,\p Stop}.
+  /// Determines the range for the affine SCEVAddRecExpr {\p Start,+,\p Step}.
   /// Helper for \c getRange.
@@ -1443,15 +1443,15 @@
 
   /// Try to compute a range for the affine SCEVAddRecExpr {\p Start,+,\p
-  /// Stop} by "factoring out" a ternary expression from the add recurrence.
+  /// Step} by "factoring out" a ternary expression from the add recurrence.
   /// Helper called by \c getRange.
A non-text attachment was scrubbed...
Name: D73857.241949.patch
Type: text/x-patch
Size: 1355 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20200202/52c481dc/attachment.bin>


More information about the llvm-commits mailing list